@@ -39,12 +39,13 @@ def build_dataloader(dataset: Dataset,
                                                              rank=comm.get_local_rank(),
                                                              shuffle=shuffle)
         shuffle = False  # sampler option is mutually exclusive with shuffle
+    # fix a bug: torch<=1.6 have no argument 'persistent_workers'
+    kwargs["persistent_workers"] = persistent_workers
     dataloader = torch_utils.DataLoader(dataset,
                                         batch_size=batch_size,
                                         num_workers=num_workers,
                                         sampler=sampler,
                                         shuffle=shuffle,
-                                        persistent_workers=persistent_workers,
                                         **kwargs)
     return dataloader
 
